# Copyright (C) 2022 MicroSys Electronics GmbH
# Author: Kay Potthoff <kay.potthoff@microsys.de>

inherit deploy

MICROSYS_IMAGE_EXTRA_INSTALL += " \
    parted e2fsprogs-resize2fs can-utils bashprofile \
    stressapptest whetstone dhrystone iperf3 memtester \
"

#MICROSYS_IMAGE_EXTRA_INSTALL_mpxls1028 += "${@bb.utils.contains('DISTRO_FEATURES', \
#                                   'systemd', 'systemd', '', d)}"

IMAGE_INSTALL += "${MICROSYS_IMAGE_EXTRA_INSTALL}"

# LS1028A DisplayPort Firmware
#IMAGE_INSTALL_append_mpxls1028 = " ls1028a-dp-fw"
#IMAGE_INSTALL_remove_mpxls1028 = "packagegroup-fsl-virtualization"
#IMAGE_INSTALL_append_mpxls1028 = " imx-gpu-viv-demos "

IMAGE_INSTALL_append_mpxls1046crx06 = " sja1105-tool"
IMAGE_INSTALL_append_mpxls1088crx06 = " sja1105-tool"
IMAGE_INSTALL_append += " fmc "

SDCARD_ROOTFS = "${IMGDEPLOYDIR}/${IMAGE_BASENAME}-${MACHINE}.ext4"

DEPENDS += " parted-native u-boot u-boot-qoriq-binman qoriq-atf"
RDEPENDS += " parted-native u-boot-qoriq-binman qoriq-atf"

DEPENDS += "microsys-image-ramdisk"

do_image_ext4[depends] += "e2fsprogs-native:do_populate_sysroot"
do_image_ext3[depends] += "e2fsprogs-native:do_populate_sysroot"
do_image_sdcard[rdeptask] += "do_rootfs"
do_image_sdcard[rdeptask] += "do_image_ext4"
do_image_ext4[rdeptask] += "do_image_kernelitb"
do_image_tar[rdeptask] += "do_image_kernelitb"
do_image_tfa_sdcard[rdeptask] += "linux-qoriq:do_deploy"
do_rootfs_kernelitb[rdeptask] += "linux-qoriq:do_deploy"
do_rootfs_kernelitb[rdeptask] += "linux-qoriq:do_bundle_initramfs"

IMAGE_FSTYPES_remove = "ext2.gz"
IMAGE_FSTYPES_remove = "ext2.gz.u-boot"
IMAGE_FSTYPES += "ext4 sdcard ubi"
IMAGE_FSTYPES_qoriq += "ext4 tfa-sdcard tar.gz"

IMAGE_TYPES_remove = "ubi"

#IMAGE_INSTALL_remove_mpxls1028 = "packagegroup-fsl-virtualization"

#IMAGE_FEATURES_mpxls1028 += " \
#    ${@bb.utils.contains('DISTRO_FEATURES', 'wayland', '', \
#       bb.utils.contains('DISTRO_FEATURES', 'x11', 'x11-base', \
#                         '', d), d)} \
#    debug-tweaks \
#    tools-testapps \
#    tools-profile \
#"

#CORE_IMAGE_EXTRA_INSTALL_mpxls1028 += " \
#    ${@bb.utils.contains('DISTRO_FEATURES', 'x11', \
#                         'packagegroup-core-x11 packagegroup-core-x11-base', \
#                         '', d)} \
#    packagegroup-fsl-tools-benchmark \
#    packagegroup-fonts-truetype \
#    ${@bb.utils.contains('DISTRO_FEATURES', 'wayland', \
#                         'weston weston-init', '', d)} \
#    ${@bb.utils.contains('DISTRO_FEATURES', 'x11 wayland', \
#                         'weston-xwayland xterm', '', d)} \
#    ${@bb.utils.contains('DISTRO_FEATURES', 'xfce', \
#                         'packagegroup-xfce-base', '', d)} \
#    ${@bb.utils.contains('DISTRO_FEATURES', 'qt5', \
#                         'packagegroup-qt5-toolchain-target', '', d)} \
#    ${@bb.utils.contains('DISTRO_FEATURES', 'qt5', \
#                         'ttf-dejavu-common \
#                          ttf-dejavu-sans ttf-dejavu-sans-mono ttf-dejavu-sans-condensed \
#                          ttf-dejavu-serif ttf-dejavu-serif-condensed', '', d)} \
#    ${@bb.utils.contains('DISTRO_FEATURES', 'qt5', \
#                         'cinematicexperience qt5nmapcarousedemo qt5everywheredemo qtsmarthome qt5-demo-extrafiles qt5ledscreen', '', d)} \
#"

do_rootfs_kernelitb() {
	cp -a ${DEPLOY_DIR_IMAGE}/fitImage*.itb ${IMAGE_ROOTFS}/boot

	#bbplain "MicroSys Release Version: "${DISTRO_VERSION}
	#cp -a ${DEPLOY_DIR_IMAGE}/ramdisk_image.bin ${IMAGE_ROOTFS}/boot/ramdisk_image-${DISTRO_VERSION}.bin
}
addtask rootfs_kernelitb after do_rootfs before do_image

do_rootfs_u_boot() {

    install -d ${IMAGE_ROOTFS}/boot

    for ub in ${DEPLOY_DIR_IMAGE}/u-boot-${MACHINE}.bin-*; do
        file=$(realpath ${ub})
        target=$(basename ${ub})
        install -m 0644 ${file} ${IMAGE_ROOTFS}/boot/${target}
    done

    cp -a ${DEPLOY_DIR_IMAGE}/${UBOOT_ENVBIN}-* ${IMAGE_ROOTFS}/boot
}
addtask rootfs_u_boot after do_rootfs before do_image

do_rootfs_atf() {

    install -d ${IMAGE_ROOTFS}/boot

    for bl in ${DEPLOY_DIR_IMAGE}/atf/bl2_*.pbl; do
        file=$(realpath ${bl})
        install -m 0644 ${file} ${IMAGE_ROOTFS}/boot
    done

    for fip in ${DEPLOY_DIR_IMAGE}/atf/fip*.bin; do
        file=$(realpath ${fip})
        install -m 0644 ${file} ${IMAGE_ROOTFS}/boot
    done
}
addtask rootfs_atf after do_rootfs before do_image


do_rootfs_ubootfirmwareimage() {
    export PYTHONPATH=${RECIPE_SYSROOT}${libdir}/:$PYTHONPATH

	if [ ${MACHINE} = "mpxls1046ram2gbcrx05" ]; then
		 binman build -d ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.dtb -O ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.img
		cp -a ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.img/qspi_firmware.img ${IMAGE_ROOTFS}/boot/qspi_firmware.img
    fi
	if [ ${MACHINE} = "mpxls1046ram4gbcrx05" ]; then
		binman build -d ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.dtb -O ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.img
		cp -a ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.img/qspi_firmware.img ${IMAGE_ROOTFS}/boot/qspi_firmware.img
    fi

    if [ ${MACHINE} = "mpxls1046crx06" ]; then
         	binman build -d ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.dtb -O ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.img
		cp -a ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1046.img/qspi_firmware.img ${IMAGE_ROOTFS}/boot/qspi_firmware.img
    fi

    # We are doing the same for every mpxls1043 machine
    if [ "${MACHINE}" = "mpxls1043ac1000msatacrx05" ] \
    || [ "${MACHINE}" = "mpxls1043ac1000pciecrx05" ] \
    || [ "${MACHINE}" = "mpxls1043ac1600msatacrx05" ] \
    || [ "${MACHINE}" = "mpxls1043ac1600pciecrx05" ] ; then
        binman build -d ${DEPLOY_DIR_IMAGE}/nand_firmware_mpxls1043.dtb -O ${DEPLOY_DIR_IMAGE}/nand_firmware_mpxls1043.img
        binman build -d ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1043.dtb -O ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1043.img
		cp -a ${DEPLOY_DIR_IMAGE}/nand_firmware_mpxls1043.img/nand_firmware.img ${IMAGE_ROOTFS}/boot/nand_firmware.img
		cp -a ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1043.img/qspi_firmware.img ${IMAGE_ROOTFS}/boot/qspi_firmware.img
    fi

    if [ ${MACHINE} = "mpxls1088crx05" ]; then
            	binman build -d ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.dtb -O ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.img
		cp -a ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.img/qspi_firmware.img ${IMAGE_ROOTFS}/boot/qspi_firmware.img
    fi
    if [ ${MACHINE} = "mpxls1088crx06" ]; then
         	binman build -d ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.dtb -O ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.img
		cp -a ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.img/qspi_firmware.img ${IMAGE_ROOTFS}/boot/qspi_firmware.img
    fi
    if [ ${MACHINE} = "mpxls1088crx06qsgmii" ]; then
         	binman build -d ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.dtb -O ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.img
		cp -a ${DEPLOY_DIR_IMAGE}/qspi_firmware_mpxls1088.img/qspi_firmware.img ${IMAGE_ROOTFS}/boot/qspi_firmware.img
    fi
    if [ ${MACHINE} = "mpxlx2160acrx08" ]; then
		 binman build -d ${DEPLOY_DIR_IMAGE}/xspi_firmware_mpxlx2160_crx08.dtb -O ${DEPLOY_DIR_IMAGE}/xspi_firmware_mpxlx2160_crx08.img
		cp -a ${DEPLOY_DIR_IMAGE}/xspi_firmware_mpxlx2160_crx08.img/xspi_firmware.img ${IMAGE_ROOTFS}/boot/xspi_firmware.img
    fi
    if [ ${MACHINE} = "mpxlx2160acrx08ai" ]; then
		 binman build -d ${DEPLOY_DIR_IMAGE}/xspi_firmware_mpxlx2160_crx08.dtb -O ${DEPLOY_DIR_IMAGE}/xspi_firmware_mpxlx2160_crx08.img
		cp -a ${DEPLOY_DIR_IMAGE}/xspi_firmware_mpxlx2160_crx08.img/xspi_firmware.img ${IMAGE_ROOTFS}/boot/xspi_firmware.img
    fi

}
addtask rootfs_ubootfirmwareimage after do_rootfs before do_image

do_rootfs_modify_dppa_udev_rules() {

    if [ ${MACHINE} = "mpxls1046crx06" ]; then
       echo "SUBSYSTEM==\"net\", DRIVERS==\"fsl_dpa*\", ATTR{device_addr}==\"1af2000\", NAME=\"fm1-mac10\"" >> ${IMAGE_ROOTFS}/${sysconfdir}/udev/rules.d/73-fsl-dpaa-persistent-networking.rules
    fi
	if [ ${MACHINE} = "mpxls1088crx06" ]; then
       echo "SUBSYSTEM==\"net\", DRIVERS==\"fsl_dpa*\", ATTR{device_addr}==\"1af2000\", NAME=\"fm1-mac10\"" >> ${IMAGE_ROOTFS}/${sysconfdir}/udev/rules.d/73-fsl-dpaa-persistent-networking.rules
    fi
	if [ ${MACHINE} = "mpxls1088crx06qsgmii" ]; then
       echo "SUBSYSTEM==\"net\", DRIVERS==\"fsl_dpa*\", ATTR{device_addr}==\"1af2000\", NAME=\"fm1-mac10\"" >> ${IMAGE_ROOTFS}/${sysconfdir}/udev/rules.d/73-fsl-dpaa-persistent-networking.rules
    fi
}
addtask rootfs_modify_dppa_udev_rules after do_rootfs before do_image
